#!/usr/bin/env python

from setuptools import setup
from setuptools.command.install import install as _install

class install(_install):
    def pre_install_script(self):
        pass

    def post_install_script(self):
        pass

    def run(self):
        self.pre_install_script()

        _install.run(self)

        self.post_install_script()

if __name__ == '__main__':
    setup(
        name = 'deep-genome-core',
        version = '1.0.0',
        description = '''Genome analysis library''',
        long_description = '''Deep Genome Core (DG Core) is a bioinformatics library for writing
bioinformatics algorithms, mainly used by the Deep Genome projects.

Links
=====

-  `Documentation <http://pythonhosted.org/deep-genome-core/>`__
-  `PyPI <https://pypi.python.org/pypi/deep-genome-core/>`__
-  `GitLab <https://gitlab.psb.ugent.be/deep_genome/core>`__

API stability
=============

While all features are documented (docstrings only) and tested, the API
is changed frequently. When doing so, the `major version <semver_>`__ is
bumped and a changelog is kept to help upgrade. Fixes will not be
backported. It is recommended to pin the major version in your setup.py,
e.g. for 2.x.y:

::

    install_requires = ['deep-genome-core>=2.0.0,<3.0.0', ...]

If you see something you like but need long term stability (e.g. if low
maintenance cost is required), request to have it moved to a stable
library (one with fewer major releases) by `opening an
issue <https://gitlab.psb.ugent.be/deep_genome/core/issues>`__.

Changelog
=========

`Semantic versioning <semver_>`__ is used.

v1.0.0
------

Initial release.
''',
        author = "VIB/BEG/UGent, Tim Diels",
        author_email = "info@psb.ugent.be, timdiels.m@gmail.com",
        license = 'LGPLv3',
        url = 'https://gitlab.psb.ugent.be/deep_genome/core',
        scripts = [],
        packages = [
            'deep_genome',
            'deep_genome.core',
            'deep_genome.core.database',
            'deep_genome.core.pipeline'
        ],
        namespace_packages = [],
        py_modules = [],
        classifiers = [
            'Development Status :: 2 - Pre-Alpha',
            'Intended Audience :: Developers',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved',
            'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
            'Natural Language :: English',
            'Operating System :: POSIX',
            'Operating System :: POSIX :: AIX',
            'Operating System :: POSIX :: BSD',
            'Operating System :: POSIX :: BSD :: BSD/OS',
            'Operating System :: POSIX :: BSD :: FreeBSD',
            'Operating System :: POSIX :: BSD :: NetBSD',
            'Operating System :: POSIX :: BSD :: OpenBSD',
            'Operating System :: POSIX :: GNU Hurd',
            'Operating System :: POSIX :: HP-UX',
            'Operating System :: POSIX :: IRIX',
            'Operating System :: POSIX :: Linux',
            'Operating System :: POSIX :: Other',
            'Operating System :: POSIX :: SCO',
            'Operating System :: POSIX :: SunOS/Solaris',
            'Operating System :: Unix',
            'Programming Language :: Python',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3 :: Only',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: Implementation',
            'Programming Language :: Python :: Implementation :: CPython',
            'Programming Language :: Python :: Implementation :: Stackless',
            'Topic :: Scientific/Engineering',
            'Topic :: Scientific/Engineering :: Bio-Informatics',
            'Topic :: Software Development',
            'Topic :: Software Development :: Libraries',
            'Topic :: Software Development :: Libraries :: Python Modules'
        ],
        entry_points = {
            'console_scripts': []
        },
        data_files = [],
        package_data = {},
        install_requires = [
            'attrs',
            'bottleneck',
            'chicken-turtle-util[path,exceptions,inspect,data_frame,series,test,pymysql,sqlalchemy]<5.0.0,>=4.0.0',
            'click',
            'drmaa',
            'inflection',
            'more_itertools',
            'numexpr',
            'numpy',
            'pandas',
            'plumbum',
            'psutil',
            'pymysql',
            'scikit-learn',
            'scipy',
            'sqlalchemy'
        ],
        dependency_links = [],
        zip_safe=True,
        cmdclass={'install': install},
        keywords='bioinformatics genome-analysis',
    )
